@@ -30,11 +30,11 @@
 //
 
 // For username research
-#if defined(Q_WS_WIN)
+#if defined(Q_OS_WIN32)
 #include <lmcons.h>
 #else
 #include <unistd.h>
-#endif
+#endif // #if defined(Q_OS_WIN32)
 
 // Qt style headers
 #include <qcdestyle.h>
@@ -213,7 +213,7 @@ void Titraqform::setupActions(void)
     m_pFilequitact = new QAction(trUtf8("Exit"), trUtf8("E&xit"), CTRL+Key_Q, this, "Exit");
     if (m_pFilequitact == NULL)     // Sanity check
         throw Genexcept("Main window file quit action creation failed.");
-    connect(m_pFilequitact, SIGNAL(activated()), qApp, SLOT(quit()));
+    connect(m_pFilequitact, SIGNAL(activated()), this, SLOT(close()));
 
     // Cut action
     m_pCutact = new QAction(trUtf8("Cut"), QPixmap(s_kpcCut_xpm), trUtf8("&Cut"), CTRL+Key_X, this, "Cut");
@@ -249,7 +249,7 @@ void Titraqform::setupActions(void)
     m_pPasteact->setWhatsThis(kszPastetext);
 
     // Add data row action
-    m_pAddrowact = new QAction(trUtf8("Add Row"), QPixmap(s_kpcRowadd_xpm), trUtf8("&Add row"), CTRL+Key_A, this, "Addrow");
+    m_pAddrowact = new QAction(trUtf8("Add Row"), QPixmap(s_kpcRowadd_xpm), trUtf8("&Add row"), Key_Insert, this, "Addrow");
     if (m_pAddrowact == NULL)       // Sanity check
         throw Genexcept("Main window add row action creation failed.");
     connect(m_pAddrowact, SIGNAL(activated()), this, SLOT(addEntry()));
@@ -260,7 +260,7 @@ void Titraqform::setupActions(void)
     m_pAddrowact->setWhatsThis(kszAddrowtext);
 
     // Delete data row action
-    m_pDelrowact = new QAction(trUtf8("Delete Row"), QPixmap(s_kpcRowdel_xpm), trUtf8("&Delete row"), CTRL+Key_D, this, "Delrow");
+    m_pDelrowact = new QAction(trUtf8("Delete Row"), QPixmap(s_kpcRowdel_xpm), trUtf8("&Delete row"), Key_Delete, this, "Delrow");
     if (m_pDelrowact == NULL)       // Sanity check
         throw Genexcept("Main window delete row action creation failed.");
     connect(m_pDelrowact, SIGNAL(activated()), this, SLOT(delEntry()));
@@ -331,7 +331,8 @@ void Titraqform::setupMenubar(void)
 
     // Populate the view menu with subitems
     m_pMenubar->insertItem(trUtf8("&View"), m_pViewpopup);
-    m_pViewpopup->insertItem(trUtf8("&Normal"), this, SLOT(normalView()));
+    nMenuid = m_pViewpopup->insertItem(trUtf8("&Normal"), this, SLOT(normalView()));
+    m_pViewpopup->setItemEnabled(nMenuid, false);
     nMenuid = m_pViewpopup->insertItem(trUtf8("&Editing"), this, SLOT(editingView()));
     m_pViewpopup->setItemEnabled(nMenuid, false);
     nMenuid = m_pViewpopup->insertItem(trUtf8("&Timing"), this, SLOT(timingView()));
@@ -346,24 +347,30 @@ void Titraqform::setupMenubar(void)
     m_pTbarspopup->setItemChecked(nMenuid, true);
     m_pViewpopup->insertSeparator();
     m_pViewpopup->insertItem(trUtf8("&Columns"), m_pColspopup);
+    nMenuid = m_pColspopup->insertItem(trUtf8("&Status"), this, SLOT(showStatcol()));
+    m_pColspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pColspopup->insertItem(trUtf8("&Line"), this, SLOT(showLinecol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
-    nMenuid = m_pColspopup->insertItem(trUtf8("&GUID"), this, SLOT(showGuidcol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
-    nMenuid = m_pColspopup->insertItem(trUtf8("&Date"), this, SLOT(showDatecol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
+    m_pColspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pColspopup->insertItem(trUtf8("&User"), this, SLOT(showUsercol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
-    nMenuid = m_pColspopup->insertItem(trUtf8("&Task"), this, SLOT(showTaskcol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
+    m_pColspopup->setItemChecked(nMenuid, true);
+    nMenuid = m_pColspopup->insertItem(trUtf8("&GUID"), this, SLOT(showGuidcol()));
+    m_pColspopup->setItemChecked(nMenuid, true);
+    nMenuid = m_pColspopup->insertItem(trUtf8("&CRC"), this, SLOT(showCrccol()));
+    m_pColspopup->setItemChecked(nMenuid, true);
+    nMenuid = m_pColspopup->insertItem(trUtf8("&Rev"), this, SLOT(showRevcol()));
+    m_pColspopup->setItemChecked(nMenuid, true);
+    nMenuid = m_pColspopup->insertItem(trUtf8("&Date"), this, SLOT(showDatecol()));
+    m_pColspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pColspopup->insertItem(trUtf8("&Start"), this, SLOT(showStartcol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
+    m_pColspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pColspopup->insertItem(trUtf8("&Finish"), this, SLOT(showFinishcol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
+    m_pColspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pColspopup->insertItem(trUtf8("&Amount"), this, SLOT(showAmountcol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
+    m_pColspopup->setItemChecked(nMenuid, true);
+    nMenuid = m_pColspopup->insertItem(trUtf8("&Task"), this, SLOT(showTaskcol()));
+    m_pColspopup->setItemChecked(nMenuid, true);
     nMenuid = m_pColspopup->insertItem(trUtf8("&Remark"), this, SLOT(showRemarkcol()));
-    m_pColspopup->setItemEnabled(nMenuid, false);
+    m_pColspopup->setItemChecked(nMenuid, true);
 
     // Pad spacing to force help menu to appear far right
     m_pMenubar->insertSeparator();
@@ -373,7 +380,8 @@ void Titraqform::setupMenubar(void)
     if (pHelppopup == NULL) // Sanity check
         throw Genexcept("Main window help popup creation failed.");
     m_pMenubar->insertItem(trUtf8("&Help"), pHelppopup);
-    pHelppopup->insertItem(trUtf8("&Contents"), this, SLOT(helpContents()), Key_F1);
+    nMenuid = pHelppopup->insertItem(trUtf8("&Contents"), this, SLOT(helpContents()), Key_F1);
+    pHelppopup->setItemEnabled(nMenuid, false);
     pHelppopup->insertSeparator();
     pHelppopup->insertItem(trUtf8("About &Titraq"), this, SLOT(aboutTitraq()));
     pHelppopup->insertItem(trUtf8("About &OSSP"), this, SLOT(aboutOSSP()));
@@ -383,9 +391,9 @@ void Titraqform::setupMenubar(void)
 }
 
 //
-// Construct the file tool bar
+// Construct the tool bars
 //
-void Titraqform::setupFiletools(void)
+void Titraqform::setupToolbars(void)
 {
     // Construct and populate the file tool bar
     m_pFiletools = new QToolBar("Toolfile", this, DockTop);
@@ -468,7 +476,7 @@ void Titraqform::setupTable(void)
     m_pMaintable = new TiTable(m_pCenframe, "Maintable");
     if (m_pMaintable == NULL)   // Sanity check
         throw Genexcept("Main window table creation failed.");
-    m_pMaintable->setNumCols(g_knCols);
+    m_pMaintable->setNumCols(TITRAQ_IDXTAIL);
     m_pMaintable->setReadOnly(true);                    // Table is read only
     m_pMaintable->setColumnMovingEnabled(false);        // Ctrl-drag disabled
     m_pMaintable->setSelectionMode(QTable::MultiRow);   // Multi row selection
@@ -477,19 +485,41 @@ void Titraqform::setupTable(void)
     m_pMaintable->setLeftMargin(0);             // Get rid of the vertical header
     m_pMaintable->verticalHeader()->hide();     // by hiding it with a margin of 0
     m_pMaintable->horizontalHeader()->setResizeEnabled(true);
-    m_pMaintable->horizontalHeader()->setClickEnabled(true); // No click signals
+    m_pMaintable->horizontalHeader()->setClickEnabled(true); // Allow click signals
     m_pMaintable->horizontalHeader()->setTracking(false); // No continuous tracking
-    m_pMaintable->setColumnStretchable(g_knCols - 1, true);
+    m_pMaintable->setColumnStretchable(TITRAQ_IDXTAIL - 1, true);
     m_pMaintable->setSorting(false);
 
     // Table header row
     m_pTablehead = m_pMaintable->horizontalHeader();
     m_pMaintable->setHScrollBarMode(QScrollView::AlwaysOff);
-    m_pTablehead->setLabel(TITRAQ_IDXDATE, QObject::trUtf8("Date"), 90);
-    m_pTablehead->setLabel(TITRAQ_IDXSTART, QObject::trUtf8("Begin"), 80);
-    m_pTablehead->setLabel(TITRAQ_IDXFINISH, QObject::trUtf8("End"), 80);
-    m_pTablehead->setLabel(TITRAQ_IDXAMOUNT, QObject::trUtf8("Amount"), 98);
-    m_pTablehead->setLabel(TITRAQ_IDXTASK, QObject::trUtf8("Task"), 96);
+    m_pTablehead->setLabel(TITRAQ_IDXSTATUS, QObject::trUtf8("Stat"),
+        m_pPrefs->getNumber(TITRAQ_PREFSTATCOLWIDTH, TITRAQ_DEFSTATCOLWIDTH));
+    m_pMaintable->setColumnReadOnly (TITRAQ_IDXSTATUS, true);
+    m_pTablehead->setLabel(TITRAQ_IDXLINE, QObject::trUtf8("Line"),
+        m_pPrefs->getNumber(TITRAQ_PREFLCOLWIDTH, TITRAQ_DEFLCOLWIDTH));
+    m_pMaintable->setColumnReadOnly (TITRAQ_IDXLINE, true);
+    m_pTablehead->setLabel(TITRAQ_IDXUSER, QObject::trUtf8("User"),
+        m_pPrefs->getNumber(TITRAQ_PREFUCOLWIDTH, TITRAQ_DEFUCOLWIDTH));
+    m_pTablehead->setLabel(TITRAQ_IDXGUID, QObject::trUtf8("GUID"),
+        m_pPrefs->getNumber(TITRAQ_PREFGCOLWIDTH, TITRAQ_DEFGCOLWIDTH));
+    m_pMaintable->setColumnReadOnly (TITRAQ_IDXGUID, true);
+    m_pTablehead->setLabel(TITRAQ_IDXCRC, QObject::trUtf8("CRC"),
+        m_pPrefs->getNumber(TITRAQ_PREFCCOLWIDTH, TITRAQ_DEFCCOLWIDTH));
+    m_pMaintable->setColumnReadOnly (TITRAQ_IDXCRC, true);
+    m_pTablehead->setLabel(TITRAQ_IDXREV, QObject::trUtf8("Rev"),
+        m_pPrefs->getNumber(TITRAQ_PREFREVCOLWIDTH, TITRAQ_DEFREVCOLWIDTH));
+    m_pMaintable->setColumnReadOnly (TITRAQ_IDXREV, true);
+    m_pTablehead->setLabel(TITRAQ_IDXDATE, QObject::trUtf8("Date"),
+        m_pPrefs->getNumber(TITRAQ_PREFDCOLWIDTH, TITRAQ_DEFDCOLWIDTH));
+    m_pTablehead->setLabel(TITRAQ_IDXSTART, QObject::trUtf8("Begin"),
+        m_pPrefs->getNumber(TITRAQ_PREFSTARTCOLWIDTH, TITRAQ_DEFSTARTCOLWIDTH));
+    m_pTablehead->setLabel(TITRAQ_IDXFINISH, QObject::trUtf8("End"),
+        m_pPrefs->getNumber(TITRAQ_PREFFCOLWIDTH, TITRAQ_DEFFCOLWIDTH));
+    m_pTablehead->setLabel(TITRAQ_IDXAMOUNT, QObject::trUtf8("Amount"),
+        m_pPrefs->getNumber(TITRAQ_PREFACOLWIDTH, TITRAQ_DEFACOLWIDTH));
+    m_pTablehead->setLabel(TITRAQ_IDXTASK, QObject::trUtf8("Task"),
+        m_pPrefs->getNumber(TITRAQ_PREFTCOLWIDTH, TITRAQ_DEFTCOLWIDTH));
     m_pTablehead->setLabel(TITRAQ_IDXREMARK, QObject::trUtf8("Remark"));
 
     m_pPackagelayout->addWidget(m_pMaintable);  // Finally add the damn table
@@ -498,7 +528,8 @@ void Titraqform::setupTable(void)
     connect(m_pMaintable, SIGNAL(currentChanged(int, int)), this, SLOT(updEdit(int, int)));
     connect(m_pMaintable, SIGNAL(doubleClicked(int, int, int, const QPoint&)), this, SLOT(inplaceEdit(int, int, int, const QPoint&)));
     connect(m_pTablehead, SIGNAL(sizeChange(int, int, int)), this, SLOT(updSizes(int, int, int)));
-    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(dataChanged(int, int)));
+    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(dataChanged(void)));
+    connect(m_pMaintable, SIGNAL(textEdited(void)), this, SLOT(dataChanged(void)));
 }
 
 //
@@ -509,6 +540,115 @@ void Titraqform::setupEditlay(void)
 //    QSpacerItem Pad(TITRAQ_SPACING / 2, 0, QSizePolicy::Fixed);
 //    m_pEditlayout->addWidget(&Pad); // Padd left side of control layout
 
+    // Make the status edit
+    m_pStatusedit = new QLineEdit(m_pCenframe, "Status");
+    if (m_pStatusedit == NULL) // Sanity check
+        throw Genexcept("Main window status edit creation failed.");
+    m_pStatusedit->setText(trUtf8("0"));
+    m_pStatusedit->setFrameShape(QLineEdit::LineEditPanel);
+    m_pStatusedit->setFrameShadow(QLineEdit::Sunken);
+    m_pStatusedit->setFrame(true);
+    m_pStatusedit->setReadOnly(true);
+    QToolTip::add(m_pStatusedit, trUtf8("Status Item"));
+    m_pEditlayout->addWidget(m_pStatusedit);  // Finally add the item status edit
+
+    // Whatsthis info for the item status edit
+    const char *kszStatustext = "The <em>item status</em> shows a green "
+                                "symbol for valid entries, a yellow symbol "
+                                "to warn, and a red symbol for flawed entries.";
+    QWhatsThis::add(m_pStatusedit, kszStatustext);
+
+    // Make the line number edit
+    m_pLineedit = new QLineEdit(m_pCenframe, "Lineno");
+    if (m_pLineedit == NULL) // Sanity check
+        throw Genexcept("Main window line number edit creation failed.");
+    m_pLineedit->setText(trUtf8("0"));
+    m_pLineedit->setFrameShape(QLineEdit::LineEditPanel);
+    m_pLineedit->setFrameShadow(QLineEdit::Sunken);
+    m_pLineedit->setFrame(true);
+    m_pLineedit->setReadOnly(true);
+    m_pLineedit->setAlignment(Qt::AlignRight);
+    QToolTip::add(m_pLineedit, trUtf8("Line Number"));
+    m_pEditlayout->addWidget(m_pLineedit);  // Finally add the line number edit
+
+    // Whatsthis info for the line number edit
+    const char *kszLinenotext = "The <em>line number</em> helps identify "
+                                "an entry when a warning or error message "
+                                "appears.";
+    QWhatsThis::add(m_pLineedit, kszLinenotext);
+
+    // Make the user edit
+    m_pUseredit = new QLineEdit(m_pCenframe, "User");
+    if (m_pUseredit == NULL) // Sanity check
+        throw Genexcept("Main window user edit creation failed.");
+    m_pUseredit->setText(m_pPrefs->getString(TITRAQ_PREFUSER, TITRAQ_DEFUSER));
+    m_pUseredit->setFrameShape(QLineEdit::LineEditPanel);
+    m_pUseredit->setFrameShadow(QLineEdit::Sunken);
+    m_pUseredit->setFrame(true);
+    m_pUseredit->setReadOnly(false);
+    QToolTip::add(m_pUseredit, trUtf8("User Name"));
+    m_pEditlayout->addWidget(m_pUseredit);  // Finally add the user edit
+
+    // Whatsthis info for the user edit
+    const char *kszUsertext = "Edit the <em>user name</em> by clicking "
+                              "on this control and typing the user name "
+                              "you want to account.";
+    QWhatsThis::add(m_pUseredit, kszUsertext);
+
+    // Make the GUID edit
+    m_pGuidedit = new QLineEdit(m_pCenframe, "Guid");
+    if (m_pGuidedit == NULL) // Sanity check
+        throw Genexcept("Main window GUID edit creation failed.");
+    m_pGuidedit->setText(trUtf8("."));
+    m_pGuidedit->setFrameShape(QLineEdit::LineEditPanel);
+    m_pGuidedit->setFrameShadow(QLineEdit::Sunken);
+    m_pGuidedit->setFrame(true);
+    m_pGuidedit->setReadOnly(true);
+    QToolTip::add(m_pGuidedit, trUtf8("GUID"));
+    m_pEditlayout->addWidget(m_pGuidedit);  // Finally add the GUID edit
+
+    // Whatsthis info for the GUID edit
+    const char *kszGuidtext = "Edit the <em>GUID</em> by clicking "
+                              "on this control and typing the GUID "
+                              "corresponding to this account item.";
+    QWhatsThis::add(m_pGuidedit, kszGuidtext);
+
+    // Make the CRC edit
+    m_pCrcedit = new QLineEdit(m_pCenframe, "Crc");
+    if (m_pCrcedit == NULL) // Sanity check
+        throw Genexcept("Main window CRC edit creation failed.");
+    m_pCrcedit->setText(trUtf8("."));
+    m_pCrcedit->setFrameShape(QLineEdit::LineEditPanel);
+    m_pCrcedit->setFrameShadow(QLineEdit::Sunken);
+    m_pCrcedit->setFrame(true);
+    m_pCrcedit->setReadOnly(true);
+    QToolTip::add(m_pCrcedit, trUtf8("CRC"));
+    m_pEditlayout->addWidget(m_pCrcedit);  // Finally add the CRC edit
+
+    // Whatsthis info for the CRC edit
+    const char *kszCrctext = "Edit the <em>CRC</em> by clicking "
+                             "on this control and typing the new "
+                             "value for this account item.";
+    QWhatsThis::add(m_pCrcedit, kszCrctext);
+
+    // Make the revision edit
+    m_pRevedit = new QLineEdit(m_pCenframe, "Revision");
+    if (m_pRevedit == NULL) // Sanity check
+        throw Genexcept("Main window revision edit creation failed.");
+    m_pRevedit->setText(trUtf8("."));
+    m_pRevedit->setFrameShape(QLineEdit::LineEditPanel);
+    m_pRevedit->setFrameShadow(QLineEdit::Sunken);
+    m_pRevedit->setFrame(true);
+    m_pRevedit->setReadOnly(true);
+    QToolTip::add(m_pRevedit, trUtf8("Revision"));
+    m_pEditlayout->addWidget(m_pRevedit);  // Finally add the revision edit
+
+    // Whatsthis info for the revision edit
+    const char *kszRevtext = "Edit the <em>revision</em> by clicking "
+                             "on this control and typing the new value "
+                             "for this account type.";
+    QWhatsThis::add(m_pRevedit, kszRevtext);
+
     // Make the date selector
     m_pDateedit = new QDateEdit(m_pCenframe, "Date");
     m_pDatezero = new QDate(m_pDateedit->date());                   // Hack to store empty date
@@ -610,7 +750,7 @@ void Titraqform::setupEditlay(void)
         m_pTasks->listBox()->setHScrollBarMode(QScrollView::Auto);
 //        m_pTasks->setMinimumWidth(m_pTasks->listBox()->maxItemWidth());
 
-    // Whatsthis info for the remark line
+    // Whatsthis info for the task editor
     const char *kszTasktext = "Choose a <em>task account</em> by clicking on "
                               "this box, and choosing whichever item most "
                               "closely resembles your task.";
@@ -637,7 +777,13 @@ void Titraqform::setupEditlay(void)
     // Start edit controls off at right size
     this->updSizes(TITRAQ_IDXALLCTRLS, -1, -1);
 
-    // Signals
+    // Signals sent between table cells and corresponding edit control widgets
+    connect(m_pStatusedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateStatus(const QString &)));
+    connect(m_pLineedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateLine(const QString &)));
+    connect(m_pUseredit, SIGNAL(textChanged(const QString &)), this, SLOT(updateUser(const QString &)));
+    connect(m_pGuidedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateGuid(const QString &)));
+    connect(m_pCrcedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateCrc(const QString &)));
+    connect(m_pRevedit, SIGNAL(textChanged(const QString &)), this, SLOT(updateRev(const QString &)));
     connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), this, SLOT(updateDate(const QDate &)));
     connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), this, SLOT(updateStart(const QTime &)));
     connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), this, SLOT(updateFinish(const QTime &)));
@@ -645,3 +791,49 @@ void Titraqform::setupEditlay(void)
     connect(m_pTasks, SIGNAL(textChanged(const QString &)), this, SLOT(updateTask(const QString &)));
     connect(m_pRemark, SIGNAL(textChanged(const QString &)), this, SLOT(updateRemark(const QString &)));
 }
+
+//
+// Arrange and configure columns
+//
+void Titraqform::setupColumns(void)
+{
+    // Handle column view handling presets and defaults
+    if (!m_pPrefs->getBool(TITRAQ_PREFSTATCOLON, TITRAQ_DEFSTATCOLON))
+        showStatcol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFLCOLON, TITRAQ_DEFLCOLON))
+        showLinecol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFUCOLON, TITRAQ_DEFUCOLON))
+        showUsercol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFGCOLON, TITRAQ_DEFGCOLON))
+        showGuidcol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFCCOLON, TITRAQ_DEFCCOLON))
+        showCrccol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFREVCOLON, TITRAQ_DEFREVCOLON))
+        showRevcol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFDCOLON, TITRAQ_DEFDCOLON))
+        showDatecol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFSTARTCOLON, TITRAQ_DEFSTARTCOLON))
+        showStartcol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFFCOLON, TITRAQ_DEFFCOLON))
+        showFinishcol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFACOLON, TITRAQ_DEFACOLON))
+        showAmountcol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFTCOLON, TITRAQ_DEFTCOLON))
+        showTaskcol();
+    if (!m_pPrefs->getBool(TITRAQ_PREFREMCOLON, TITRAQ_DEFREMCOLON))
+        showRemarkcol();
+
+    // Handle tool bar view handling presets and defaults
+    if (!m_pPrefs->getBool(TITRAQ_PREFFILEBAR, TITRAQ_DEFFILEBAR)) {
+        m_pFiletools->hide();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXFILEBAR), false);
+    }
+    if (!m_pPrefs->getBool(TITRAQ_PREFEDITBAR, TITRAQ_DEFEDITBAR)) {
+        m_pEdittools->hide();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXEDITBAR), false);
+    }
+    if (!m_pPrefs->getBool(TITRAQ_PREFWHATBAR, TITRAQ_DEFWHATBAR)) {
+        m_pWhatstools->hide();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXWHATBAR), false);
+    }
+}
