@@ -58,7 +58,6 @@
 
 // Main table size
 const int g_knBlocks = 32;
-const int g_knCols = 6;
 
 // Styles enumeration
 typedef enum
@@ -85,6 +84,7 @@ public:
     void setDirty(bool bDirty = true) {m_bDirt = bDirty;};  // Clean or dirty
     const QString getRowdata(void) const;                   // Get a whole row of data
     void setRowdata(QString &) const;                       // Set a whole row of data
+    const int getFirstcol(void) const;                      // Learn which col is first
 
     // Top level members
     Preferences *m_pPrefs;
@@ -104,12 +104,18 @@ public:
 
     // Edition widgets
     QDate       *m_pDatezero;           // Hack to store empty date
-    QDateEdit   *m_pDateedit;           // Control used to edit dates
-    QTimeEdit   *m_pStarttime;          // Control used to edit start time
-    QTimeEdit   *m_pEndtime;            // Control used to edit finish time
-    AmountBox   *m_pAmount;             // Control used to edit total time
-    QComboBox   *m_pTasks;              // Control used to choose a task
-    QLineEdit   *m_pRemark;             // Control used to edit remark
+    QLineEdit   *m_pStatusedit;         // Control to show entry status
+    QLineEdit   *m_pLineedit;           // Control to line number
+    QLineEdit   *m_pUseredit;           // Control to edit user name
+    QLineEdit   *m_pGuidedit;           // Control to edit GUID
+    QLineEdit   *m_pCrcedit;            // Control to edit CRC
+    QLineEdit   *m_pRevedit;            // Control to edit revision
+    QDateEdit   *m_pDateedit;           // Control to edit date
+    QTimeEdit   *m_pStarttime;          // Control to edit start time
+    QTimeEdit   *m_pEndtime;            // Control to edit finish time
+    AmountBox   *m_pAmount;             // Control to edit total time
+    QComboBox   *m_pTasks;              // Control to choose a task
+    QLineEdit   *m_pRemark;             // Control to edit remark
 
 protected slots:
     void cutEntry(void);                // Cut task entries from the list
@@ -129,7 +135,13 @@ protected slots:
     void inplaceEdit(int, int, int, const QPoint &); // Enter in place edit mode
     void updEdit(int, int);             // Update edit controls
     void updSizes(int, int, int);       // Update edit sizes
-    void dataChanged(int, int);         // Timesheet data changed
+    void dataChanged(void);             // Timesheet data changed
+    void updateStatus(const QString &); // Update status column
+    void updateLine(const QString &);   // Update line number column
+    void updateUser(const QString &);   // Update user column
+    void updateGuid(const QString &);   // Update GUID column
+    void updateCrc(const QString &);    // Update CRC column
+    void updateRev(const QString &);    // Update rev column
     void updateDate(const QDate &);     // Update date column
     void updateStart(const QTime &);    // Update start column
     void updateFinish(const QTime &);   // Update finish column
@@ -144,15 +156,19 @@ protected slots:
     void showFilebar(void);             // View menu show file toolbar
     void showEditbar(void);             // View menu show edit toolbar
     void showWhatsbar(void);            // View menu show whats this toolbar
+    void showStatcol(void);             // View menu show status column
     void showLinecol(void);             // View menu show line numbers column
-    void showGuidcol(void);             // View menu show GUIDs column
-    void showDatecol(void);             // View menu show Dates column
     void showUsercol(void);             // View menu show Users column
-    void showTaskcol(void);             // View menu show Tasks column
+    void showGuidcol(void);             // View menu show GUIDs column
+    void showCrccol(void);              // View menu show CRC column
+    void showRevcol(void);              // View menu show Rev column
+    void showDatecol(void);             // View menu show Dates column
     void showStartcol(void);            // View menu show Start time column
     void showFinishcol(void);           // View menu show Finish time column
     void showAmountcol(void);           // View menu show Amounts column
+    void showTaskcol(void);             // View menu show Tasks column
     void showRemarkcol(void);           // View menu show Remarks column
+    void savePrefs(void);               // Save user preferences
 
 protected:
     // Application main events
@@ -179,18 +195,19 @@ private:
     QString     *m_szFilename;
 
     // Standard members
-    bool        m_bDirt;                    // To track dirty and clean states
+    bool        m_bDirt;                // To track dirty and clean states
 
     // Constructor helpers
     void setupPrefs(void);              // Preferences
     void setupActions(void);            // Actions
     void setupMenubar(void);            // Menu bar
-    void setupFiletools(void);          // Tool bar
+    void setupToolbars(void);           // Tool bars
     void setupStatusbar(void);          // Status bar
     void setupCentralwidget(void);      // Assemble main Frame widget
     void setupTable(void);              // Table widget
     void setupEditlay(void);            // Editing lay
     void setupPieces(void);             // Assemble widget pieces
+    void setupColumns(void);            // Arrange and configure columns
 
     // Data processing
     void loadData(QFile &);             // Load accounting data from file
