@@ -55,12 +55,16 @@ public:
     const int getEdition(void) {return m_nEdit;};   // Which edited column was confirmed
     void setEdition(const int nEdit = -1) {m_nEdit = nEdit;};   // Set edition status
 
-//    // Overridden accessors
+    // Overridden accessors
+    void setText(int, int, const QString &);
 //    virtual QTableItem *item(int nRow, int nCol) const {QTable::item(nRow, nCol);};
 
     // Deny a cell special handling of the focus rectangle
     // by overriding class QTable's paintFocus method
     virtual void paintFocus(QPainter *, const QRect &) {};
+
+signals:
+    void textEdited(void);  // A cell was edited and data was modified
 };
 
 #endif // TITABLE_H
